Learn R Programming

IDSpatialStats (version 0.4.0)

get.tau.typed.permute: get the null distribution for the get.tau.typed function

Description

get the null distribution for the get.tau.typed function

Usage

get.tau.typed.permute(
  posmat,
  typeA = -1,
  typeB = -1,
  r = 1,
  r.low = rep(0, length(r)),
  permutations,
  comparison.type = "representative",
  data.frame = TRUE
)

Value

a matrix with permutation tau values for each distance specified

Arguments

posmat

a matrix with columns type, x and y

typeA

the "from" type that we are interested in, -1 is wildcard

typeB

the "to" type that we are interested i, -1 is wildcard

r

the series of spatial distances we are interested in

r.low

the low end of each range....0 by default

permutations

the number of permute iterations

comparison.type

what type of points are included in the comparison set.

  • "representative" if comparison set is representative of the underlying population

  • "independent" if comparison set is cases/events coming from an indepedent process

data.frame

logical indicating whether to return results as a data frame (default = TRUE)

Author

Justin Lessler and Henrik Salje

See Also

Other get.tau: get.tau(), get.tau.bootstrap(), get.tau.ci(), get.tau.permute(), get.tau.typed(), get.tau.typed.bootstrap()

Examples

Run this code
# \donttest{

data(DengueSimulationR02)

r.max<-seq(20,1000,20)
r.min<-seq(0,980,20)
r.mid<-(r.max+r.min)/2

#Lets see if there's a difference in spatial dependence by time case occurs
type <- 2 - (DengueSimR02[,"time"] < 120)
tmp <- cbind(DengueSimR02, type=type)

typed.tau <- get.tau.typed(tmp, typeA=1, typeB=2, r=r.max, r.low=r.min, 
                           comparison.type = "independent")

typed.tau.type.null<-get.tau.typed.permute(tmp, typeA=1, typeB=2, r=r.max, r.low=r.min, 
                                           permutations=100, comparison.type = "independent")

null.ci <- apply(typed.tau.type.null[,-(1:2)], 1, quantile, probs=c(0.025,0.975))

plot(r.mid, typed.tau$tau, ylim=c(0.3,4), log="y", cex.axis=1.25, 
     xlab="Distance (m)", ylab="Tau", cex.main=0.9, lwd=2, type="n")
abline(h=1,lty=1)
lines(r.mid,typed.tau$tau,pch=20,col=1,lwd=3)
lines(r.mid, null.ci[1,] , lty=2)
lines(r.mid, null.ci[2,] , lty=2)

# }

Run the code above in your browser using DataLab